@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: setup.py 11914 2020-02-09 13:48:38Z Lavender $
+# $Id: setup.py 11971 2020-03-09 06:39:08Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2020-02-09 21:48:38 +0800 (週日, 09 二月 2020) $
-# $Revision: 11914 $
+# $Date: 2020-03-09 14:39:08 +0800 (週一, 09 三月 2020) $
+# $Revision: 11971 $
 
 import os
 import sys
@@ -159,8 +159,9 @@ def sendLog(data):
 
 if not sys.version_info.major == 3:
     logger.warning(
-        colored("Python 2.7 support will be removed next version"
+        colored("Python 2.7 are not supported"
                 ", please consider upgrade to Python 3", "yellow"))
+    sys.exit(1)
 
 def copyToPath(baseDir, templateDir, staticDir, mode):
     if not templateDir:
@@ -447,6 +448,7 @@ if __name__ == "__main__":
             help="Run the configuration wizard")   
        
         args = parser.parse_args()
+        cmd = "python setup.py %s" % " ".join(sys.argv[1:])
         
         try:
             if os.path.isfile(os.path.join(SETUP_DIR, 'MANIFAST.INFO')):
@@ -471,18 +473,27 @@ if __name__ == "__main__":
             sys.exit(1)
         else:
             djangoVersion = djangoVersionTable[djangoVersion]
-
+            
         try:
-            os.system("pip install -U \"django%s\"" % djangoVersion)
+            import django
+            djangoVersion = "%d.%d.%d" % (
+                django.VERSION[0], django.VERSION[1], django.VERSION[2],)
+                
+            if not "%d.%d" % (django.VERSION[0], django.VERSION[1]) in djangoVersionTable:
+                logger.warning(colored(
+                    ("Your current Django version is %s which is not fully tested version for Django CMS themes. "
+                     "It should work, but if you encounter any problem, we recommend you switch to Django>=2.2,<2.3") % 
+                     djangoVersion, 
+                    "yellow", attrs=['bold'])
+                )
         except Exception as e:
             logger.error(
-                colored("Can't install django%s" % djangoVersion, 
-                        "red"))
-            sys.exit(1)
+                colored("Can't find django, try to install.", "yellow"))
+            os.system("pip install -U \"django%s\"" % djangoVersion)
             
-        import django
-        djangoVersion = "%d.%d.%d" % (
-            django.VERSION[0], django.VERSION[1], django.VERSION[2],)
+            import django
+            djangoVersion = "%d.%d.%d" % (
+                django.VERSION[0], django.VERSION[1], django.VERSION[2],)
         
         # modify django schema.py
         # issue: https://github.com/django/django/pull/10733/commits/c8ffdbe514b55ff5c9a2b8cb8bbdf2d3978c188f
@@ -516,6 +527,9 @@ if __name__ == "__main__":
             installVersion = "1.2.0"
         else:
             installVersion = "1.2.0"
+            logger.warning(colored(
+                "Not support django-cms<3.6", "yellow"))
+            sys.exit(1)
             
         sendLog({
             "level": "INFO",
@@ -524,6 +538,7 @@ if __name__ == "__main__":
             "cmsVersion": str(cmsVersion),
             "python": str(sys.version_info),
             "upc": upc,
+            "command": cmd,
         })
            
         path = args.path
@@ -531,7 +546,7 @@ if __name__ == "__main__":
         settingsPath = findSettings(path)
         
         createProject = False
-       
+        
         if not settingsPath:
             if not projectName:
                 if sys.version_info.major == 3:
@@ -718,7 +733,18 @@ if __name__ == "__main__":
             print("")
             logger.error(
                 colored("Please check the project's db was migrated.", "red"))
-            raise
+            sendLog({
+                "level": "ERROR",
+                "error": traceback.format_exc(),
+                "exception": "Loaddata Error",
+                "djangoVersion": djangoVersion,
+                "cmsVersion": str(cmsVersion),
+                "python": str(sys.version_info),
+                "upc": upc,
+                "createProject": str(createProject),
+                "command": cmd,
+            })
+            sys.exit(1)
         else:
             attrs=['bold']
             print("")
@@ -758,6 +784,8 @@ if __name__ == "__main__":
             "cmsVersion": str(cmsVersion),
             "python": str(sys.version_info),
             "upc": upc,
+            "createProject": str(createProject),
+            "command": cmd,
         })
         traceback.print_exc()
         print("")
@@ -772,6 +800,10 @@ if __name__ == "__main__":
             "10733/commits/c8ffdbe514b55ff5c9a2b8cb8bbdf2d3978c188f", "yellow"))
         logger.error(
             colored("to modify your schema.py to fix this problem.", "red"))
+        logger.error(colored(
+            "If you encounter \"No such file or directory: "
+            "/env/python3/lib/pythonx.x/site-packages/Django-x.x.x.dist-info/METADATA\" "
+            "Please execute setup.py again.", "red"))
     try:
         import json
         if os.path.isfile(os.path.join(SETUP_DIR, 'MANIFAST.INFO')):
