@@ -15,10 +15,19 @@
 # $Date: 2018-05-14 17:46:32 +0800 (週一, 14 五月 2018) $
 # $Revision: 11055 $
 
-from django.conf.urls import url, patterns, include
+from django.conf.urls import url, include
 from django.contrib.sitemaps.views import sitemap
 
 from Zephyrus.seo.Sitemaps import sitemaps
+from Iuppiter.DjangoUtil import DJANGO_VERSION
+
+def patterns(prefix, *args): 
+    if DJANGO_VERSION >= 11100: # django >= 1.11
+        return list(args)
+    else:
+        from django.conf.urls import patterns as _patterns
+        
+        return _patterns(prefix, *args)
 
 def attachURLs(settings, urlpatterns):
     """
